class NotFoundError(Exception):
    pass


class InvalidQueryError(Exception):
    pass


class KeyExistsError(Exception):
    pass


class InvalidValueError(Exception):
    pass


class InvalidSourceError(Exception):
    pass
